"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = useShortcut;
var _element = require("@wordpress/element");
var _useShortcutEventMatch = _interopRequireDefault(require("./use-shortcut-event-match"));
var _context = require("../context");
/**
 * WordPress dependencies
 */

/**
 * Internal dependencies
 */

/**
 * Attach a keyboard shortcut handler.
 *
 * @param {string}   name               Shortcut name.
 * @param {Function} callback           Shortcut callback.
 * @param {Object}   options            Shortcut options.
 * @param {boolean}  options.isDisabled Whether to disable to shortut.
 */
function useShortcut(name, callback, {
  isDisabled = false
} = {}) {
  const shortcuts = (0, _element.useContext)(_context.context);
  const isMatch = (0, _useShortcutEventMatch.default)();
  const callbackRef = (0, _element.useRef)();
  (0, _element.useEffect)(() => {
    callbackRef.current = callback;
  }, [callback]);
  (0, _element.useEffect)(() => {
    if (isDisabled) {
      return;
    }
    function _callback(event) {
      if (isMatch(name, event)) {
        callbackRef.current(event);
      }
    }
    shortcuts.add(_callback);
    return () => {
      shortcuts.delete(_callback);
    };
  }, [name, isDisabled, shortcuts]);
}
//# sourceMappingURL=use-shortcut.js.map